# anupam-action-test
 <img src="[https://s3.amazonaws.com/nrjio/interactive.gif](https://compote.slate.com/images/697b023b-64a5-49a0-8059-27b963453fb1.gif?crop=780%2C520%2Cx0%2Cy0&width=1280)https://compote.slate.com/images/697b023b-64a5-49a0-8059-27b963453fb1.gif?crop=780%2C520%2Cx0%2Cy0&width=1280" alt="Interactive notifications example" width=350/>
